@@ -152,9 +152,9 @@ comments_get_comment_filename (const char *source,
 			       gboolean    unescape) 
 {
 	char        *source_real = NULL;
-	char        *directory;
-	const char  *filename;
-	char        *path;
+	char        *directory = NULL;
+	const char  *filename = NULL;
+	char        *path = NULL;
 
 	if (source == NULL) 
 		return NULL;
@@ -163,18 +163,13 @@ comments_get_comment_filename (const char *source,
 
 	if (resolve_symlinks) {
 		char           *parent;
-		char           *parent_escaped;
 		char           *parent_resolved;
 		GnomeVFSResult  result;
 
 		parent = remove_level_from_path (source);
-		parent_escaped = gnome_vfs_escape_path_string (parent);
+		result = resolve_all_symlinks (parent, &parent_resolved);
 		g_free (parent);
 
-		result = resolve_all_symlinks (parent_escaped, 
-					       &parent_resolved);
-		g_free (parent_escaped);
-
 		if (result == GNOME_VFS_OK) { 
 			g_free (source_real);
 			source_real = g_strconcat (parent_resolved, 
@@ -221,14 +216,8 @@ comments_get_comment_dir (const char *directory,
 	char        *path;
 
 	if (resolve_symlinks && (directory != NULL)) {
-		char           *directory_escaped;
 		GnomeVFSResult  result;
-
-		directory_escaped = gnome_vfs_escape_path_string (directory);
-		result = resolve_all_symlinks (directory_escaped, 
-					       &directory_resolved);
-		g_free (directory_escaped);
-
+		result = resolve_all_symlinks (directory, &directory_resolved);
 		if (result == GNOME_VFS_OK) 
 			directory_real = directory_resolved;
 	}
@@ -261,8 +250,8 @@ void
 comment_copy (const char *src,
 	      const char *dest)
 {
-	char *comment_src;
-	char *comment_dest;
+	char *comment_src = NULL;
+	char *comment_dest = NULL;
 
 	comment_src = comments_get_comment_filename (src, TRUE, TRUE);
 	if (! path_is_file (comment_src)) {
@@ -288,8 +277,8 @@ void
 comment_move (const char *src,
 	      const char *dest)
 {
-	char *comment_src;
-	char *comment_dest;
+	char *comment_src = NULL;
+	char *comment_dest = NULL;
 
 	comment_src = comments_get_comment_filename (src, TRUE, TRUE);
 	if (! path_is_file (comment_src)) {
@@ -583,11 +572,11 @@ save_comment (const char  *filename,
 {
 	xmlDocPtr    doc;
         xmlNodePtr   tree, subtree;
-	char        *comment_file;
-	char        *time_str;
-	char        *keywords_str;
-	char        *dest_dir;
-	char        *e_comment, *e_place, *e_keywords;
+	char        *comment_file = NULL;
+	char        *time_str = NULL;
+	char        *keywords_str = NULL;
+	char        *dest_dir = NULL;
+	char        *e_comment = NULL, *e_place = NULL, *e_keywords = NULL;
 
 	if (comment_data_is_void (data)) {
 		comment_delete (filename);
