@@ -1412,107 +1412,112 @@ new_uri_from_path (const char *path)
 }
 
 
-/* taken from gnome-vfs-utils.c,
-     Copyright (C) 1999 Free Software Foundation
-     Copyright (C) 2000, 2001 Eazel, Inc.
-*/
-GnomeVFSResult
-resolve_all_symlinks_uri (GnomeVFSURI  *uri,
-			  GnomeVFSURI **result_uri)
+char *
+new_path_from_uri (GnomeVFSURI *uri)
 {
-	GnomeVFSURI      *new_uri, *resolved_uri;
+	char *path;
+	char *unescaped_path;
+
+	path = gnome_vfs_uri_to_string (uri, GNOME_VFS_URI_HIDE_TOPLEVEL_METHOD);
+	unescaped_path = gnome_vfs_unescape_string (path, NULL);
+	g_free (path);
+
+	return unescaped_path;
+}
+
+
+GnomeVFSResult
+resolve_all_symlinks (const char  *text_uri,
+		      char       **resolved_text_uri)
+{
+	GnomeVFSResult    res = GNOME_VFS_OK;
+	char             *my_text_uri;
 	GnomeVFSFileInfo *info;
-	GnomeVFSResult    res;
-	char             *p;
-	int               n_followed_symlinks;
+	const char       *p;
+	int               n_followed_symlinks = 0;
 
-	/* Ref the original uri so we don't lose it */
-	uri = gnome_vfs_uri_ref (uri);
+	*resolved_text_uri = NULL;
 
-	*result_uri = NULL;
+	if (text_uri == NULL) 
+		return res;
 
+	my_text_uri = g_strdup (text_uri);
 	info = gnome_vfs_file_info_new ();
 
-	p = uri->text;
-	n_followed_symlinks = 0;
-	while (*p != 0) {
+	for (p = my_text_uri; *p != 0;) {
+		char           *new_text_uri;
+		GnomeVFSURI    *new_uri;
+
 		while (*p == GNOME_VFS_URI_PATH_CHR)
 			p++;
 		while (*p != 0 && *p != GNOME_VFS_URI_PATH_CHR)
 			p++;
 
-		new_uri = gnome_vfs_uri_dup (uri);
-		g_free (new_uri->text);
-		new_uri->text = g_strndup (uri->text, p - uri->text);
+		new_text_uri = g_strndup (my_text_uri, p - my_text_uri);
+		new_uri = new_uri_from_path (new_text_uri);
+		g_free (new_text_uri);
 
 		gnome_vfs_file_info_clear (info);
 		res = gnome_vfs_get_file_info_uri (new_uri, info, GNOME_VFS_FILE_INFO_DEFAULT);
+
 		if (res != GNOME_VFS_OK) {
 			gnome_vfs_uri_unref (new_uri);
 			goto out;
 		}
+
 		if (info->type == GNOME_VFS_FILE_TYPE_SYMBOLIC_LINK &&
 		    info->valid_fields & GNOME_VFS_FILE_INFO_FIELDS_SYMLINK_NAME) {
+			GnomeVFSURI *resolved_uri;
+			char        *resolved_text_uri = NULL;
+
 			n_followed_symlinks++;
 			if (n_followed_symlinks > MAX_SYMLINKS_FOLLOWED) {
 				res = GNOME_VFS_ERROR_TOO_MANY_LINKS;
 				gnome_vfs_uri_unref (new_uri);
 				goto out;
 			}
-			resolved_uri = gnome_vfs_uri_resolve_relative (new_uri,
-								       info->symlink_name);
+
+			resolved_uri = gnome_vfs_uri_resolve_relative (new_uri, info->symlink_name);
+			resolved_text_uri = new_path_from_uri (resolved_uri);
+			gnome_vfs_uri_unref (resolved_uri);
+
 			if (*p != 0) {
-				GnomeVFSURI *old_uri = uri;
-				uri = gnome_vfs_uri_append_string (resolved_uri, p);
-				gnome_vfs_uri_unref (old_uri);
-				gnome_vfs_uri_unref (resolved_uri);
+				char *old_uri = my_text_uri;
+				my_text_uri = g_build_filename (resolved_text_uri, p, NULL);
+				g_free (old_uri);
+				g_free (resolved_text_uri);
 			} else {
-				gnome_vfs_uri_unref (uri);
-				uri = resolved_uri;
+				g_free (my_text_uri);
+				my_text_uri = resolved_text_uri;
 			}
 
-			p = uri->text;
-		} 
-		gnome_vfs_uri_unref (new_uri);
+			p = my_text_uri;
+		}
+
+		gnome_vfs_uri_unref (new_uri); 
 	}
 
 	res = GNOME_VFS_OK;
-	*result_uri = gnome_vfs_uri_dup (uri);
+	*resolved_text_uri = my_text_uri;
  out:
 	gnome_vfs_file_info_unref (info);
-	gnome_vfs_uri_unref (uri);
 	return res;
 }
 
 
-/* taken from gnome-vfs-utils.c,
-     Copyright (C) 1999 Free Software Foundation
-     Copyright (C) 2000, 2001 Eazel, Inc.
-*/
-GnomeVFSResult
-resolve_all_symlinks (const char  *text_uri,
-		      char       **resolved_text_uri)
+GnomeVFSFileSize
+get_dest_free_space (const char  *path)
 {
-	GnomeVFSURI    *uri, *resolved_uri;
-	GnomeVFSResult  res;
-
-	*resolved_text_uri = NULL;
-
-	uri = gnome_vfs_uri_new (text_uri);
-	if (uri == NULL || uri->text == NULL) {
-		if (uri != NULL)
-			gnome_vfs_uri_unref (uri);
-		return GNOME_VFS_ERROR_NOT_SUPPORTED;
-	}
-
-	res = resolve_all_symlinks_uri (uri, &resolved_uri);
-
-	if (res == GNOME_VFS_OK) {
-		*resolved_text_uri = gnome_vfs_uri_to_string (resolved_uri, GNOME_VFS_URI_HIDE_TOPLEVEL_METHOD);
-		gnome_vfs_uri_unref (resolved_uri);
-	}
+	GnomeVFSURI      *uri;
+	GnomeVFSResult    result;
+	GnomeVFSFileSize  ret_val;
 
+	uri = new_uri_from_path (path);
+	result = gnome_vfs_get_volume_free_space (uri, &ret_val);
 	gnome_vfs_uri_unref (uri);
 
-	return res;
+	if (result != GNOME_VFS_OK)
+		return (GnomeVFSFileSize) 0;
+	else
+		return ret_val;
 }
