@@ -50,8 +50,6 @@ static PangoRectangle  bounds;
 static GtkWidget      *popup_window = NULL;
 static GtkWidget      *prop_button = NULL;
 static FullScreen     *current_fullscreen;
-static int             main_window_x;
-static int             main_window_y;
 
 
 static void
@@ -224,7 +222,9 @@ get_file_info (GThumbWindow *window)
 	tm = localtime (&timer);
 	strftime (time_txt, 50, _("%d %B %Y, %H:%M"), tm);
 
-	file_info = g_strdup_printf ("%s\n%s (%d%%) - %s - %s ",
+	file_info = g_strdup_printf ("%d/%d - <tt>%s</tt>\n<i>%s (%d%%) - %s - %s </i>",
+				     gth_file_list_pos_from_path (window->file_list, window->image_path) + 1,
+				     gth_file_list_get_length (window->file_list),
 				     e_filename,
 				     size_txt,
 				     zoom,
@@ -291,10 +291,10 @@ show_comment_on_image (GThumbWindow *window,
 	file_info = get_file_info (window);
 
 	if (comment == NULL)
-		marked_text = g_strdup_printf ("<i>%s</i>", file_info);
+		marked_text = g_strdup (file_info); /*g_strdup_printf ("<i>%s</i>", file_info);*/
 	else {
 		e_comment = g_markup_escape_text (comment, -1);
-		marked_text = g_strdup_printf ("<b>%s</b>\n<i>%s</i>", 
+		marked_text = g_strdup_printf ("<b>%s</b>\n%s", 
 					       e_comment, 
 					       file_info);
 		g_free (e_comment);
@@ -432,6 +432,7 @@ image_key_press_cb (GtkWidget   *widget,
 	case GDK_Escape:
 	case GDK_q:
 	case GDK_v:
+	case GDK_f:
 	case GDK_F11:
 		fullscreen_stop (fullscreen);
 		break;
@@ -565,8 +566,8 @@ image_key_press_cb (GtkWidget   *widget,
 		break;
 
 		/* Flip image. */
-	case GDK_f:
-	case GDK_F:
+	case GDK_l:
+	case GDK_L:
 		alter_image_flip_command_impl (NULL, window, NULL);
 		break;
 
@@ -953,13 +954,9 @@ fullscreen_start (FullScreen   *fullscreen,
 
 	current_fullscreen = fullscreen;
 
-	gtk_widget_hide (window->app);
+	gtk_window_set_screen (GTK_WINDOW (fullscreen->window), gtk_widget_get_screen (window->app));
 	gtk_window_present (GTK_WINDOW (fullscreen->window));
 
-	gtk_window_get_position (GTK_WINDOW (window->app),
-				 &main_window_x,
-				 &main_window_y);
-
 	window->fullscreen = TRUE;
 	fullscreen->related_win = window;
 	fullscreen->viewer = window->viewer;
@@ -1037,6 +1034,7 @@ fullscreen_stop (FullScreen *fullscreen)
 	if (! eel_gconf_get_boolean (PREF_BLACK_BACKGROUND, FALSE))
 		image_viewer_set_black_background (IMAGE_VIEWER (fullscreen->viewer), FALSE);
 
+	gtk_widget_hide (fullscreen->window);
 	wmspec_change_state (FALSE,
 			     fullscreen->window->window,
 			     gdk_atom_intern ("_NET_WM_STATE_FULLSCREEN", 
@@ -1075,10 +1073,6 @@ fullscreen_stop (FullScreen *fullscreen)
 
 	gtk_widget_show_all (window->app);
 
-	gtk_window_move (GTK_WINDOW (window->app),
-			 main_window_x,
-			 main_window_y);
-
 	/* restore widgets visiblity */
 
 	window_set_preview_content (window, window->preview_content);
@@ -1088,8 +1082,4 @@ fullscreen_stop (FullScreen *fullscreen)
 		window_show_sidebar (window);
 	else 
 		window_hide_sidebar (window);
-
-	/**/
-
-	gtk_widget_hide (fullscreen->window);
 }
